@@ -1,5 +1,5 @@
 from pangres.core import upsert
-from pangres.utils import fix_psycopg2_bad_cols
+from pangres.utils import adjust_chunksize, fix_psycopg2_bad_cols
 from pangres.examples import DocsExampleTable
 from pangres._version import __version__
 from pangres.exceptions import *
\ No newline at end of file
